@@ -6,7 +6,8 @@ Begin a marked-content sequence terminated by a balancing EMC
 operator. tag shall be a name object indicating the role or significance of
 the sequence.
 """
-from typing import List
+
+import typing
 
 from borb.io.read.types import AnyPDFType, Name
 from borb.pdf.canvas.operator.canvas_operator import CanvasOperator
@@ -22,7 +23,12 @@ class BeginMarkedContent(CanvasOperator):
     def __init__(self):
         super().__init__("BMC", 1)
 
-    def invoke(self, canvas_stream_processor: "CanvasStreamProcessor", operands: List[AnyPDFType] = []) -> None:  # type: ignore [name-defined]
+    def invoke(
+        self,
+        canvas_stream_processor: "CanvasStreamProcessor",  # type: ignore [name-defined]
+        operands: typing.List[AnyPDFType] = [],
+        event_listeners: typing.List["EventListener"] = [],  # type: ignore [name-defined]
+    ) -> None:
         """
         Invoke the BMC operator
         """
