@@ -6,8 +6,8 @@ Set the horizontal scaling, Th , to (scale ÷ 100). scale shall be a number
 specifying the percentage of the normal width. Initial value: 100 (normal
 width).
 """
+import typing
 from decimal import Decimal
-from typing import List
 
 from borb.io.read.types import AnyPDFType
 from borb.pdf.canvas.operator.canvas_operator import CanvasOperator
@@ -23,7 +23,12 @@ class SetHorizontalScaling(CanvasOperator):
     def __init__(self):
         super().__init__("Tz", 1)
 
-    def invoke(self, canvas_stream_processor: "CanvasStreamProcessor", operands: List[AnyPDFType] = []) -> None:  # type: ignore [name-defined]
+    def invoke(
+        self,
+        canvas_stream_processor: "CanvasStreamProcessor",  # type: ignore [name-defined]
+        operands: typing.List[AnyPDFType] = [],
+        event_listeners: typing.List["EventListener"] = [],  # type: ignore [name-defined]
+    ) -> None:
         """
         Invoke the Tz operator
         """
