@@ -11,6 +11,7 @@ import io
 import typing
 
 import PIL  # type: ignore [import]
+
 from borb.io.read.types import AnyPDFType, Dictionary, Name, Stream
 from borb.pdf.canvas.event.image_render_event import ImageRenderEvent
 from borb.pdf.canvas.operator.canvas_operator import CanvasOperator
@@ -32,7 +33,12 @@ class Do(CanvasOperator):
     def __init__(self):
         super().__init__("Do", 1)
 
-    def invoke(self, canvas_stream_processor: "CanvasStreamProcessor", operands: typing.List[AnyPDFType] = []):  # type: ignore [name-defined]
+    def invoke(
+        self,
+        canvas_stream_processor: "CanvasStreamProcessor",  # type: ignore [name-defined]
+        operands: typing.List[AnyPDFType] = [],
+        event_listeners: typing.List["EventListener"] = [],  # type: ignore [name-defined]
+    ) -> None:
         """
         Invoke the Do operator
         """
@@ -47,9 +53,12 @@ class Do(CanvasOperator):
 
         # render Image objects
         if isinstance(xobject, PIL.Image.Image):
-            canvas._event_occurred(
-                ImageRenderEvent(graphics_state=canvas.graphics_state, image=xobject)
-            )
+            for l in event_listeners:
+                l._event_occurred(
+                    ImageRenderEvent(
+                        graphics_state=canvas.graphics_state, image=xobject
+                    )
+                )
             return
 
         # Form XObject
@@ -68,7 +77,9 @@ class Do(CanvasOperator):
                     [xobject_resources]
                 )
             )
-            child_canvas_stream_processor.read(io.BytesIO(xobject["DecodedBytes"]))
+            child_canvas_stream_processor.read(
+                io.BytesIO(xobject["DecodedBytes"]), event_listeners
+            )
 
             # return
             return
