@@ -7,15 +7,10 @@
 import typing
 import xml.etree.ElementTree as ET
 
-from borb.io.read.types import Decimal
-from borb.pdf.canvas.color.color import HexColor
 from borb.pdf.canvas.layout.layout_element import LayoutElement
 from borb.pdf.canvas.layout.page_layout.page_layout import PageLayout
 from borb.pdf.canvas.layout.text.chunk_of_text import ChunkOfText
 from borb.pdf.canvas.layout.text.chunks_of_text import HeterogeneousParagraph
-from borb.pdf.canvas.layout.text.heading import Heading
-from borb.pdf.document import Document
-from borb.pdf.page.page import Page
 from borb.toolkit.export.html_to_pdf.tag_transformer.base_tag_transformer import (
     BaseTagTransformer,
 )
