@@ -5,12 +5,10 @@
 This class converts Markdown to PDF
 """
 from borb.pdf.document import Document
-from borb.toolkit.export.markdown_to_pdf.markdown_transformer.any_markdown_transformer import (
+from borb.toolkit.export.markdown_to_pdf.read.any_markdown_transformer import (
     AnyMarkdownTransformer,
 )
-from borb.toolkit.export.markdown_to_pdf.markdown_transformer.base_markdown_transformer import (
-    MarkdownTransformerState,
-)
+from borb.toolkit.export.markdown_to_pdf.read.transformer import TransformerState
 
 
 class MarkdownToPDF:
@@ -23,6 +21,6 @@ class MarkdownToPDF:
         """
         This function converts a Markdown str to a PDF
         """
-        ctx: MarkdownTransformerState = MarkdownTransformerState(markdown)
+        ctx: TransformerState = TransformerState(markdown)
         AnyMarkdownTransformer()._transform(ctx)
         return ctx.get_document()
