@@ -1,5 +1,6 @@
 import os
 import time
+import traceback
 import typing
 import unittest
 from datetime import datetime
@@ -118,7 +119,7 @@ class TestExtractTextExpectGroundTruth(unittest.TestCase):
             Paragraph(
                 "Timing Information",
                 font_color=HexColor("72A276"),
-                font_size=Decimal(18.2),
+                font_size=Decimal(14),
                 font="Helvetica-Bold",
             )
         )
@@ -126,7 +127,7 @@ class TestExtractTextExpectGroundTruth(unittest.TestCase):
             Paragraph(
                 "Failure Information",
                 font_color=HexColor("72A276"),
-                font_size=Decimal(18.2),
+                font_size=Decimal(14),
                 font="Helvetica-Bold",
             )
         )
@@ -239,7 +240,7 @@ class TestExtractTextExpectGroundTruth(unittest.TestCase):
                         "Most Error-prone Documents",
                         font_color=HexColor("72A276"),
                         font="Helvetica-Bold",
-                        font_size=Decimal(18.2),
+                        font_size=Decimal(14.2),
                     ),
                     col_span=2,
                 )
@@ -267,7 +268,7 @@ class TestExtractTextExpectGroundTruth(unittest.TestCase):
                     Paragraph(
                         "Slowest Documents",
                         font_color=HexColor("72A276"),
-                        font_size=Decimal(18.2),
+                        font_size=Decimal(14.2),
                         font="Helvetica-Bold",
                     ),
                     col_span=2,
@@ -296,7 +297,7 @@ class TestExtractTextExpectGroundTruth(unittest.TestCase):
                     Paragraph(
                         "Fastest Documents",
                         font_color=HexColor("72A276"),
-                        font_size=Decimal(18.2),
+                        font_size=Decimal(14),
                         font="Helvetica-Bold",
                     ),
                     col_span=2,
@@ -321,8 +322,11 @@ class TestExtractTextExpectGroundTruth(unittest.TestCase):
     def _test_single_document(self, file) -> typing.Dict[str, int]:
 
         txt_001 = ""
-        with open(self.corpus_dir / (file.stem + ".txt"), "r") as fh_001:
-            txt_001 = fh_001.read()
+        try:
+            with open(self.corpus_dir / (file.stem + ".txt"), "r") as fh_001:
+                txt_001 = fh_001.read()
+        except:
+            pass
 
         txt_002: str = ""
         with open(file, "rb") as fh_002:
